/*
 * include/arch/i386/klibc/archconfig.h
 *
 * See include/klibc/sysconfig.h for the options that can be set in
 * this file.
 *
 */

#ifndef _KLIBC_ARCHCONFIG_H
#define _KLIBC_ARCHCONFIG_H

/* We have klibc/archinit.h and __libc_archinit() */
#define _KLIBC_HAS_ARCHINIT 1

#endif				/* _KLIBC_ARCHCONFIG_H */
